@@ -12,14 +12,14 @@ use base qw(Net::DNS::Resolver::Base DynaLoader), OS_CONF;
 our $VERSION;
 
 BEGIN {
-	$VERSION = '1.26_02';
+	$VERSION = '1.26_03';
 	eval { __PACKAGE__->bootstrap($VERSION) };
 }
 
-use constant UNBOUND_VERSION => eval {
+use constant UNBOUND_VERSION => scalar eval {
 	my $version = Net::DNS::Resolver::libunbound->VERSION();
-	my ( $v1, $v2, $v3 ) = split /\D/, $version;
-	( $v1 * 100 + $v2 ) * 100 + $v3;
+	my ( $major, $minor, $minimus ) = split /\D/, $version;
+	( $major * 100 + $minor ) * 100 + $minimus;
 };
 
 use constant UB_CONTEXT => 'Net::DNS::Resolver::Unbound::Context';
@@ -161,19 +161,19 @@ use constant UB_SEND => UB_CONTEXT->can('ub_send');
 
 sub send {
 	my ( $self, @argument ) = @_;
+
+	my ($packet) = @argument;
+	if ( ref $packet ) {					# resolve packets asynchronously
+		my $handle = $self->bgsend(@argument);
+		return $self->bgread($handle);
+	}
+
 	$self->_finalise_config;
 	$self->_reset_errorstring;
 
-	my ($packet) = @argument;
-	my $query = $self->_make_query_packet(@argument);
-	my $result;
-	if ( UB_SEND && ref($packet) ) {
-		$result = $self->{ub_ctx}->ub_send( $query->encode );
-	} else {
-		my ($q) = $query->question;
-		$result = $self->{ub_ctx}->ub_resolve( $q->name, $q->{qtype}, $q->{qclass} );
-	}
-
+	my $query  = $self->_make_query_packet(@argument);
+	my ($q)	   = $query->question;
+	my $result = $self->{ub_ctx}->ub_resolve( $q->name, $q->{qtype}, $q->{qclass} );
 	return $self->_decode_result($result);
 }
 
@@ -203,10 +203,10 @@ sub bgread {
 	return unless $handle;
 
 	$self->{ub_ctx}->ub_wait if &bgbusy;
-
 	$self->errorstring( $handle->err );
+
 	my $reply = $self->_decode_result( $handle->result ) || return;
-	$reply->header->id( $handle->query_id );
+	$reply->header->id( $handle->query_id );		# lying toad!;
 	return $reply;
 }
 
